==> clouddriver-artifacts-2.110.0-sources.jar: com/netflix/spinnaker/clouddriver/artifacts/ivy/settings/BintrayResolver.java <==
/*
 * Copyright 2018 Pivotal, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.netflix.spinnaker.clouddriver.artifacts.ivy.settings;

import com.fasterxml.jackson.dataformat.xml.annotation.JacksonXmlProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;

import javax.annotation.Nullable;

@EqualsAndHashCode(callSuper = true)
@Data
public class BintrayResolver extends Resolver<org.apache.ivy.plugins.resolver.BintrayResolver> {
  /**
   * Bintray username of a repository owner.
   */
  @JacksonXmlProperty(isAttribute = true)
  @Nullable
  private String subject;

  /**
   * User’s repository name.
   */
  @JacksonXmlProperty(isAttribute = true)
  @Nullable
  private String repo;

  @Override
  public org.apache.ivy.plugins.resolver.BintrayResolver toIvyModel() {
    org.apache.ivy.plugins.resolver.BintrayResolver bintrayResolver = new org.apache.ivy.plugins.resolver.BintrayResolver();
    bintrayResolver.setRepo(repo);
    bintrayResolver.setSubject(subject);
    return super.toIvyModel(bintrayResolver);
  }
}

==> clouddriver-artifacts-5.72.1-sources.jar: com/netflix/spinnaker/clouddriver/artifacts/ivy/settings/BintrayResolver.java <==
/*
 * Copyright 2018 Pivotal, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.netflix.spinnaker.clouddriver.artifacts.ivy.settings;

import com.fasterxml.jackson.dataformat.xml.annotation.JacksonXmlProperty;
import javax.annotation.Nullable;
import lombok.Data;
import lombok.EqualsAndHashCode;

@EqualsAndHashCode(callSuper = true)
@Data
final class BintrayResolver extends Resolver<org.apache.ivy.plugins.resolver.BintrayResolver> {
  /** Bintray username of a repository owner. */
  @JacksonXmlProperty(isAttribute = true)
  @Nullable
  private String subject;

  /** User's repository name. */
  @JacksonXmlProperty(isAttribute = true)
  @Nullable
  private String repo;

  @Override
  public org.apache.ivy.plugins.resolver.BintrayResolver toIvyModel() {
    org.apache.ivy.plugins.resolver.BintrayResolver bintrayResolver =
        new org.apache.ivy.plugins.resolver.BintrayResolver();
    bintrayResolver.setRepo(repo);
    bintrayResolver.setSubject(subject);
    return super.toIvyModel(bintrayResolver);
  }
}
